@@ -3,12 +3,9 @@ library('testthat')
 
 context("getFIX accessors")
 
-
-
-#
 data("vcfR_test")
-#
-chrom <- create.chromR(vcfR_test, verbose = FALSE)
+data("chromR_example")
+
 
 test_that("getFIX returns a matrix", {
   expect_is(getFIX(vcfR_test), "matrix")
